package com.ruoyi.mall.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.mall.domain.MallMemberCoupon;

/**
 * 用户优惠券Service接口
 *
 * @author ruoyi
 * @date 2024-06-24
 */
public interface IMallMemberCouponService
{
    /**
     * 查询用户优惠券
     *
     * @param memberCouponId 用户优惠券主键
     * @return 用户优惠券
     */
    public MallMemberCoupon selectMallMemberCouponByMemberCouponId(Long memberCouponId);

    /**
     * 查询用户优惠券列表
     *
     * @param mallMemberCoupon 用户优惠券
     * @return 用户优惠券集合
     */
    public List<MallMemberCoupon> selectMallMemberCouponList(MallMemberCoupon mallMemberCoupon);

    /**
     * 新增用户优惠券
     *
     * @param mallMemberCoupon 用户优惠券
     * @return 结果
     */
    public int insertMallMemberCoupon(MallMemberCoupon mallMemberCoupon);

    /**
     * 修改用户优惠券
     *
     * @param mallMemberCoupon 用户优惠券
     * @return 结果
     */
    public int updateMallMemberCoupon(MallMemberCoupon mallMemberCoupon);

    /**
     * 批量删除用户优惠券
     *
     * @param memberCouponIds 需要删除的用户优惠券主键集合
     * @return 结果
     */
    public int deleteMallMemberCouponByMemberCouponIds(Long[] memberCouponIds);

    /**
     * 删除用户优惠券信息
     *
     * @param memberCouponId 用户优惠券主键
     * @return 结果
     */
    public int deleteMallMemberCouponByMemberCouponId(Long memberCouponId);

    /**
     * 查看优惠券是否可用
     *
     * @param couponId 优惠券ID
     * @param userId 用户ID
     * @return 结果
     */
    public MallMemberCoupon checkCouponUsed(Long couponId, Long userId);
}
