package com.ruoyi.mall.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.MallMemberCoupon;
import com.ruoyi.mall.service.IMallMemberCouponService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

import javax.annotation.Resource;

/**
 * 用户优惠券Controller
 *
 * @author ruoyi
 * @date 2024-06-24
 */
@RestController
@RequestMapping("/mall/mallMemberCoupon")
public class MallMemberCouponController extends BaseController
{
    @Resource
    private IMallMemberCouponService mallMemberCouponService;

    /**
     * 查询用户优惠券列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberCoupon:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallMemberCoupon mallMemberCoupon)
    {
        startPage();
        List<MallMemberCoupon> list = mallMemberCouponService.selectMallMemberCouponList(mallMemberCoupon);
        return getDataTable(list);
    }

    /**
     * 导出用户优惠券列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberCoupon:export')")
    @Log(title = "用户优惠券", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(MallMemberCoupon mallMemberCoupon)
    {
        List<MallMemberCoupon> list = mallMemberCouponService.selectMallMemberCouponList(mallMemberCoupon);
        ExcelUtil<MallMemberCoupon> util = new ExcelUtil<MallMemberCoupon>(MallMemberCoupon.class);
        return util.exportExcel(list, "用户优惠券数据");
    }

    /**
     * 获取用户优惠券详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberCoupon:query')")
    @GetMapping(value = "/{memberCouponId}")
    public AjaxResult getInfo(@PathVariable("memberCouponId") Long memberCouponId)
    {
        return AjaxResult.success(mallMemberCouponService.selectMallMemberCouponByMemberCouponId(memberCouponId));
    }

    /**
     * 新增用户优惠券
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberCoupon:add')")
    @Log(title = "用户优惠券", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallMemberCoupon mallMemberCoupon)
    {
        return toAjax(mallMemberCouponService.insertMallMemberCoupon(mallMemberCoupon));
    }

    /**
     * 修改用户优惠券
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberCoupon:edit')")
    @Log(title = "用户优惠券", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallMemberCoupon mallMemberCoupon)
    {
        return toAjax(mallMemberCouponService.updateMallMemberCoupon(mallMemberCoupon));
    }

    /**
     * 删除用户优惠券
     */
    @PreAuthorize("@ss.hasPermi('mall:mallMemberCoupon:remove')")
    @Log(title = "用户优惠券", businessType = BusinessType.DELETE)
	@DeleteMapping("/{memberCouponIds}")
    public AjaxResult remove(@PathVariable Long[] memberCouponIds)
    {
        return toAjax(mallMemberCouponService.deleteMallMemberCouponByMemberCouponIds(memberCouponIds));
    }
}
